@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "عرض الحدث كاملاً عند مشاركته",
     "When shared show only busy" : "عرض مشغول عند مشاركة الحدث",
     "When shared hide this event" : "إخفاء الحدث عند مشاركته",
+    "Confirmed" : "مؤكَّد",
+    "Tentative" : "مبدئي",
+    "Cancelled" : "ملغي",
     "Please add a title!" : "رجاءا ضِف عنوان",
     "Please select a calendar!" : "فضلاً إختر مفكرةً !",
     "Global" : "عالمي",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "إغلاق",
     "Location" : "المكان",
     "Description" : "الوصف",
+    "Event status" : "حال الحدث",
+    "Visibility when sharing" : "نوع الظهور عند المشاركة",
     "Export" : "تصدير",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "لا يمكن للتقويم حالياً دعم ميزة asset pipeline نظراً لوجود علّة في مكوّن برمجي صاعد.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "فضلاً اتصل بمدير النظام واطلب منه تعطيل خيار \"asset-pipeline.enabled\" في الإعدادات.",
@@ -84,9 +89,11 @@ OC.L10N.register(
     "Month" : "شهر",
     "Today" : "اليوم",
     "Share Calendar" : "مشاركة المفكرة",
+    "Shared" : "مشارك",
     "More" : "المزيد",
     "Edit" : "تعديل",
-    "CalDAV" : "CalDAV",
+    "Link" : "الرابط",
+    "Download" : "تحميل",
     "Share with users or groups" : "شارِك مع مستخدمين أو مجموعات",
     "can edit" : "يمكن التحرير",
     "group" : "مجموعة",
