@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Amosar l'eventu completu al compartir",
     "When shared show only busy" : "Amosar namás ocupáu al compartir",
     "When shared hide this event" : "Anubrir l'eventu al compartir",
+    "Confirmed" : "Confirmáu",
+    "Tentative" : "Tentativa",
+    "Cancelled" : "Encaboxáu",
     "Please add a title!" : "¡Por favor, amiesta un títulu!",
     "Please select a calendar!" : "¡Por favor, esbilla un calendariu!",
     "Global" : "Global",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Zarrar",
     "Location" : "Llocalización",
     "Description" : "Descripción",
+    "Event status" : "Estáu del eventu",
+    "Visibility when sharing" : "Visibilida mientres compartes",
     "Export" : "Esportar",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Por cuenta d'un bug d'upstream, el calendariu nun soporta la carauterística d'asset pipeline",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contauta col to alministrador y pídi-y que desactive la opción de configuración \"asset-pipeline.enabled\".",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Selmana",
     "Month" : "Mes",
     "Today" : "Güei",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Dalgunos eventos nesti calendariu tán francíos. Por favor, compruebe la consola JS pa más información.",
     "Share Calendar" : "Compartir calendariu",
+    "Shared" : "Compartíu",
     "More" : "Más",
     "Edit" : "Editar",
-    "CalDAV" : "CalDAV",
+    "Link" : "Enllaz",
+    "Download" : "Baxar",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "can edit" : "pue editar",
     "group" : "grupu",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "Calendariu nuevu",
     "Import scheduled" : "Importar horariu",
     "Settings" : "Axustes",
+    "Skip simple event editor" : "Saltar editor d'eventos simples",
     "Import calendar" : "Importar calendariu",
     "No Calendars selected for import" : "Nun s'esbilló nengún calendariu pa la importación",
     "Primary CalDAV address" : "Direición de calendariu CalDAV primariu",
