@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Po nasdílení zobrazit celou událost",
     "When shared show only busy" : "Po nasdílení zobrazit jako zaneprázdněné",
     "When shared hide this event" : "Po nasdílení skrýt tuto událost",
+    "Confirmed" : "Potvrzeno",
+    "Tentative" : "Dočasně",
+    "Cancelled" : "Zrušeno",
     "Please add a title!" : "Zadejte prosím název!",
     "Please select a calendar!" : "Vyberte prosím kalendář!",
     "Global" : "Globální",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Zavřít",
     "Location" : "Umístění",
     "Description" : "Popis",
+    "Event status" : "Stav události",
+    "Visibility when sharing" : "Viditelnost při sdílení",
     "Export" : "Exportovat",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Kalendář v současné chvíli nemůže nabídnout podporu pro funkci \"asset pipeline\" (spojení a komprese css a js souborů).",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontaktujte prosím svého administrátora a zeptejte se ho na zrušení funkce \"asset-pipeline.enabled\" v konfiguračním souboru.",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Týden",
     "Month" : "Měsíc",
     "Today" : "Dnes",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "V tomto kalendáři jsou některé události poškozené. Pro více informací prosím nahlédněte do JS konzole.",
     "Share Calendar" : "Sdílet kalendář",
+    "Shared" : "Sdílené",
     "More" : "Více",
     "Edit" : "Upravit",
-    "CalDAV" : "CalDAV",
+    "Link" : "Odkaz",
+    "Download" : "Stáhnout",
     "Share with users or groups" : "Sdílet s uživateli nebo skupinami",
     "can edit" : "lze upravovat",
     "group" : "skupina",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "Nový kalendář",
     "Import scheduled" : "Import načasován",
     "Settings" : "Nastavení",
+    "Skip simple event editor" : "Přeskočit jednoduchý editor události",
     "Import calendar" : "Importovat kalendář",
     "No Calendars selected for import" : "Nebyl vybrán kalendář k importu",
     "Primary CalDAV address" : "Primární adresa CalDAV",
