@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "wenn geteilt, zeige den vollständigen Termin an",
     "When shared show only busy" : "wenn geteilt, zeige nur 'beschäftigt'",
     "When shared hide this event" : "wenn geteilt, zeige den Termin nicht an",
+    "Confirmed" : "Bestätigt",
+    "Tentative" : "Vorläufig",
+    "Cancelled" : "Abgebrochen",
     "Please add a title!" : "Bitte fügen Sie einen Titel hinzu!",
     "Please select a calendar!" : "Bitte wählen Sie einen Kalender aus!",
     "Global" : "Global",
@@ -64,10 +67,10 @@ OC.L10N.register(
     "{type} at the event's end" : "{type} am Ende der Veranstaltung",
     "{type} at {time}" : "{type} um {time}",
     "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
-    "Title of the Event" : "Bezeichnung des Termins",
+    "Title of the Event" : "Titel der Veranstaltung",
     "starts" : "Beginnt",
     "ends" : "endet",
-    "All day Event" : "Ganztägiger Termin",
+    "All day Event" : "Ganztägige Veranstaltung",
     "Delete" : "Löschen",
     "Cancel" : "Abbrechen",
     "More ..." : "Mehr...",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Schließen",
     "Location" : "Ort",
     "Description" : "Beschreibung",
+    "Event status" : "Veranstaltungsstatus",
+    "Visibility when sharing" : "Geteilte Ansicht",
     "Export" : "Exportieren",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Durch einen vorgeschalteten Fehler, ist der Kalender zur Zeit nicht in der Lage eine Unterstützung für die Asset Pipeline -Funktion zur Verfügung zu stellen.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktieren Sie ihren Administrator und bitten Sie ihn, die \"asset-pipeline.enabled\" Konfiguration zu deaktivieren.",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Woche",
     "Month" : "Monat",
     "Today" : "Heute",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Einige Einträge in diesem Kalender sind fehlerhaft. Bitte überprüfen Sie die JavaScript-Konsole für weitere Informationen.",
     "Share Calendar" : "Kalender freigeben",
+    "Shared" : "Geteilt",
     "More" : "Mehr",
     "Edit" : "Bearbeiten",
-    "CalDAV" : "CalDAV",
+    "Link" : "Link",
+    "Download" : "Herunterladen",
     "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
     "can edit" : "kann bearbeiten",
     "group" : "Gruppe",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "Neuer Kalender",
     "Import scheduled" : "Import geplant",
     "Settings" : "Einstellungen",
+    "Skip simple event editor" : "Einfachen Termin-Editor überspringen",
     "Import calendar" : "Kalendar importieren",
     "No Calendars selected for import" : "Es wurde kein Kalender für den Import ausgewählt",
     "Primary CalDAV address" : "Primäre CalDAV-Adresse",
