@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Mostrar el evento completo al compartir",
     "When shared show only busy" : "Mostrar solamente ocupado al compartir",
     "When shared hide this event" : "Ocultar este evento al compartir",
+    "Confirmed" : "Confirmado",
+    "Tentative" : "Tentativo",
+    "Cancelled" : "Cancelado",
     "Please add a title!" : "¡Por favor añade un título!",
     "Please select a calendar!" : "¡Por favor selecciona un calendario!",
     "Global" : "Global",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Cerrar",
     "Location" : "Ubicación",
     "Description" : "Descripción",
+    "Event status" : "Estado del evento",
+    "Visibility when sharing" : "Visibilidad cuando se comparte",
     "Export" : "Exportar",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Debido a un bug de upstream, el calendario no soporta la funcionalidad de asset pipeline",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor contacta con el administrador y proponle que desactive la opción \"asset-pipeline.enabled'.",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Semana",
     "Month" : "Mes",
     "Today" : "Hoy",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Algunos eventos de este calendario están rotos. Por favor revise la consola JavScript para más información.",
     "Share Calendar" : "Compartir calendario",
+    "Shared" : "Compartido",
     "More" : "Más",
     "Edit" : "Editar",
-    "CalDAV" : "CalDAV",
+    "Link" : "Enlace",
+    "Download" : "Descargar",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "can edit" : "puede editar",
     "group" : "grupo",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "Nuevo calendario",
     "Import scheduled" : "Importar horario",
     "Settings" : "Ajustes",
+    "Skip simple event editor" : "Omitir el editor de evento único",
     "Import calendar" : "Importar calendario",
     "No Calendars selected for import" : "No se seleccionó un calendario para importar",
     "Primary CalDAV address" : "Direccion de calendario CalDAV primario",
