@@ -17,6 +17,7 @@ OC.L10N.register(
     "When shared show full event" : "Mostrar el evento completo al compartir",
     "When shared show only busy" : "Mostrar solo cuándo estoy ocupado al compartir",
     "When shared hide this event" : "Ocultar este evento al compartir",
+    "Cancelled" : "Cancelado",
     "Please add a title!" : "Por favor agrega un título!",
     "Please select a calendar!" : "Por favor selecciona un calendario!",
     "None" : "Ninguno",
@@ -78,8 +79,10 @@ OC.L10N.register(
     "Month" : "Mes",
     "Today" : "Hoy",
     "Share Calendar" : "Compartir calendario",
+    "Shared" : "Compartido",
     "More" : "Más",
     "Edit" : "Editar",
+    "Download" : "Descargar",
     "Share with users or groups" : "Compartir con usuarios o grupos",
     "can edit" : "puede editar",
     "group" : "grupo",
