@@ -18,6 +18,7 @@ OC.L10N.register(
     "When shared show full event" : "Kui on jagatud, siis näita kogu sündmust",
     "When shared show only busy" : "Kui on jagatud, siis näita ainult, kas on hõivatud",
     "When shared hide this event" : "Kui on jagatud, siis peida see sündmus",
+    "Cancelled" : "Tühistatud",
     "Please add a title!" : "Palu lisa pealkiri!",
     "Please select a calendar!" : "Palun vali kalender!",
     "Global" : "Üldine",
@@ -74,9 +75,11 @@ OC.L10N.register(
     "Month" : "Kuu",
     "Today" : "Täna",
     "Share Calendar" : "Jaga kalendrit",
+    "Shared" : "Jagatud",
     "More" : "Rohkem",
     "Edit" : "Muuda",
-    "CalDAV" : "CalDAV",
+    "Link" : "Link",
+    "Download" : "Lae alla",
     "can edit" : "saab muuta",
     "group" : "grupp",
     "New Calendar" : "Uus kalender",
