@@ -18,6 +18,9 @@ OC.L10N.register(
     "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
     "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
     "When shared hide this event" : "Jaettuna piilota tämä tapahtuma",
+    "Confirmed" : "Vahvistettu",
+    "Tentative" : "Alustava",
+    "Cancelled" : "Peruttu",
     "Please add a title!" : "Lisää otsikko!",
     "Please select a calendar!" : "Valitse kalenteri!",
     "None" : "Ei mitään",
@@ -69,16 +72,21 @@ OC.L10N.register(
     "Close" : "Sulje",
     "Location" : "Sijainti",
     "Description" : "Kuvaus",
+    "Event status" : "Tapahtuman tila",
+    "Visibility when sharing" : "Näkyvyys jaettaessa",
     "Export" : "Vie",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ota yhteys ylläpitoon ja pyydä poistamaan käytöstä valinta \"asset-pipeline.enabled\" asetustiedostosta.",
     "Day" : "Päivä",
     "Week" : "Viikko",
     "Month" : "Kuukausi",
     "Today" : "Tänään",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Jotkin tapahtumat tässä kalenterisas ovat rikki. Tarkista JS-konsoli saadaksesi lisätietoja.",
     "Share Calendar" : "Jaa kalenteri",
+    "Shared" : "Jaettu",
     "More" : "Lisää",
     "Edit" : "Muokkaa",
-    "CalDAV" : "CalDAV",
+    "Link" : "Linkki",
+    "Download" : "Lataa",
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "can edit" : "voi muokata",
     "group" : "ryhmä",
@@ -107,6 +115,7 @@ OC.L10N.register(
     "New calendar" : "Uusi kalenteri",
     "Import scheduled" : "Tuonti ajastettu",
     "Settings" : "Asetukset",
+    "Skip simple event editor" : "Ohita yksinkertainen tapahtumamuokkain",
     "Import calendar" : "Tuo kalenteri",
     "No Calendars selected for import" : "Kalentereita ei ole valittu tuotavaksi",
     "Primary CalDAV address" : "Ensisijainen CalDAV-osoite",
