@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Afficher l'événement complet en cas de partage",
     "When shared show only busy" : "Afficher seulement la plage horaire occupée en cas de partage",
     "When shared hide this event" : "Masquer cet événement en cas de partage",
+    "Confirmed" : "Confirmé",
+    "Tentative" : "Tentative",
+    "Cancelled" : "Annulé",
     "Please add a title!" : "Veuillez ajouter un titre !",
     "Please select a calendar!" : "Veuillez sélectionner un calendrier !",
     "Global" : "Global",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Fermer",
     "Location" : "Emplacement",
     "Description" : "Description",
+    "Event status" : "Statut de l'événement",
+    "Visibility when sharing" : "Visibilité pendant le partage",
     "Export" : "Exporter",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A cause d'un bug en amont, le calendrier ne peut actuellement pas prendre en charge la fonction de pipeline d'actifs.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Veuillez contacter votre administrateur afin de lui demander de désactiver l'option de configuration \"asset-pipeline.enabled\".",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Semaine",
     "Month" : "Mois",
     "Today" : "Auj.",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Certains événements de cet agenda sont cassés. Merci de consulter la console JS pour plus d'info.",
     "Share Calendar" : "Partager l'agenda",
+    "Shared" : "Partagé",
     "More" : "Plus",
     "Edit" : "Éditer",
-    "CalDAV" : "CalDAV",
+    "Link" : "Lien",
+    "Download" : "Télécharger",
     "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
     "can edit" : "peut modifier",
     "group" : "groupe",
