@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "כאשר משותף מציג אירוע מלא",
     "When shared show only busy" : "כאשר משותף מציג עסוק בלבד",
     "When shared hide this event" : "כאשר משותף מסתיר אירוע זה",
+    "Confirmed" : "מאושר",
+    "Tentative" : "אישור טנטטיבי",
+    "Cancelled" : "בוטל",
     "Please add a title!" : "יש להוסיף כותרת!",
     "Please select a calendar!" : "יש לבחור לוח שנה!",
     "Global" : "גלובלי",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "סגירה",
     "Location" : "מיקום",
     "Description" : "תיאור",
+    "Event status" : "סטטוס אירוע",
+    "Visibility when sharing" : "הרשאות צפייה כשמשתפים",
     "Export" : "ייצוא",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "בשל באג upstream, היומן לא יכול לספק תמיכה לתכונת asset pipeline.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "יש ליצור קשר עם המנהל שלך לבקש לנטרל את אפשרות תצורה \"asset-pipeline.enabled\".",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "שבוע",
     "Month" : "חודש",
     "Today" : "היום",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "אירועים מסויימים בלוח שנה זה פגומים. יש לבדוק את קונסולת ה- JS למידע נוסף.",
     "Share Calendar" : "שיתוף לוח שנה",
+    "Shared" : "שותף",
     "More" : "יותר",
     "Edit" : "עריכה",
-    "CalDAV" : "CalDAV",
+    "Link" : "קישור",
+    "Download" : "הורדה",
     "Share with users or groups" : "שיתוף עם משתמשים או קבוצות",
     "can edit" : "ניתן לערוך",
     "group" : "קבוצה",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "לוח שנה חדש",
     "Import scheduled" : "לוח זמנים ליבוא",
     "Settings" : "הגדרות",
+    "Skip simple event editor" : "מדלג על עורך אירוע פשוט",
     "Import calendar" : "יבוא יומן",
     "No Calendars selected for import" : "לא נבחרו יומנים ליבוא",
     "Primary CalDAV address" : "כתובת CalDAV ראשית",
