@@ -82,9 +82,11 @@ OC.L10N.register(
     "Month" : "Hónap",
     "Today" : "Ma",
     "Share Calendar" : "A naptár megosztása",
+    "Shared" : "Megosztott",
     "More" : "Több",
     "Edit" : "Szerkesztés",
-    "CalDAV" : "CalDAV",
+    "Link" : "Hivatkozás",
+    "Download" : "Letöltés",
     "Share with users or groups" : "Megosztás felhasználókkal vagy csoportokkal",
     "can edit" : "szerkesztheti",
     "group" : "csoport",
