@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Se condiviso, mostra l'evento completo",
     "When shared show only busy" : "Se condiviso, mostra solo occupato",
     "When shared hide this event" : "Se condiviso, nascondi questo evento",
+    "Confirmed" : "Confermato",
+    "Tentative" : "Provvisorio",
+    "Cancelled" : "Annullati",
     "Please add a title!" : "Aggiungi un titolo!",
     "Please select a calendar!" : "Seleziona un calendario!",
     "Global" : "Globale",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Chiudi",
     "Location" : "Posizione",
     "Description" : "Descrizione",
+    "Event status" : "Stato dell'evento",
+    "Visibility when sharing" : "Visibilità in caso di condivisione",
     "Export" : "Esporta",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa di un bug a monte, il calendario non è attualmente in grado di fornire supporto per la funzionalità di asset pipeline.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contatta il tuo amministratore e chiedigli di disabilitare l'opzione di configurazione \"asset-pipeline.enabled\".",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Settimana",
     "Month" : "Mese",
     "Today" : "Oggi",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Alcuni eventi in questo calendario sono danneggiati. Controlla la console JS per ulteriori informazioni.",
     "Share Calendar" : "Condividi calendario",
+    "Shared" : "Condiviso",
     "More" : "Altro",
     "Edit" : "Modifica",
-    "CalDAV" : "CalDAV",
+    "Link" : "Collegamento",
+    "Download" : "Scarica",
     "Share with users or groups" : "Condividi con utenti o gruppi",
     "can edit" : "può modificare",
     "group" : "gruppo",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "Nuovo calendario",
     "Import scheduled" : "Importa pianificati",
     "Settings" : "Impostazioni",
+    "Skip simple event editor" : "Salta l'editor semplice degli eventi",
     "Import calendar" : "Importa calendario",
     "No Calendars selected for import" : "Nessun calendario selezionato per l'importazione",
     "Primary CalDAV address" : "Indirizzo CalDAV principale",
