@@ -17,6 +17,7 @@ OC.L10N.register(
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
     "When shared hide this event" : "共有時にこのイベントを隠す",
+    "Cancelled" : "キャンセル済",
     "Please add a title!" : "タイトルを追加してください！",
     "Please select a calendar!" : "カレンダーを選択してください！",
     "Global" : "全般",
@@ -76,9 +77,11 @@ OC.L10N.register(
     "Month" : "月",
     "Today" : "今日",
     "Share Calendar" : "カレンダーを共有する",
+    "Shared" : "共有中",
     "More" : "もっと見る",
     "Edit" : "編集",
-    "CalDAV" : "CalDAV",
+    "Link" : "リンク",
+    "Download" : "ダウンロード",
     "Share with users or groups" : "ユーザーもしくはグループと共有",
     "can edit" : "編集を許可",
     "group" : "グループ",
