@@ -19,6 +19,7 @@ OC.L10N.register(
     "When shared show full event" : "Wann et gedeelt gouf, dann de ganzen Evenement uweisen",
     "When shared show only busy" : "Wann et gedeelt gouf, dann nëmmen als beschäftegt uweisen",
     "When shared hide this event" : "Wann et gedeelt gouf, dann verstopp dëst Evenement",
+    "Cancelled" : "Ofgebrach",
     "Please add a title!" : "Setz w.e.g. nach en Titel derbäi!",
     "Please select a calendar!" : "Wiel w.e.gl e Kalenner aus!",
     "Global" : "Global",
@@ -83,8 +84,11 @@ OC.L10N.register(
     "Month" : "Mount",
     "Today" : "Haut",
     "Share Calendar" : "Kalenner deelen",
+    "Shared" : "Gedeelt",
     "More" : "Méi",
     "Edit" : "Änneren",
+    "Link" : "Link",
+    "Download" : "Eroflueden",
     "Share with users or groups" : "Mat Benotzer oder Gruppen deelen",
     "can edit" : "kann änneren",
     "group" : "Grupp",
