@@ -79,9 +79,11 @@ OC.L10N.register(
     "Month" : "Mėnuo",
     "Today" : "Šiandien",
     "Share Calendar" : "Dalintis kalendoriumi",
+    "Shared" : "Dalinamasi",
     "More" : "Daugiau",
     "Edit" : "Redaguoti",
-    "CalDAV" : "CalDAV",
+    "Link" : "Nuoroda",
+    "Download" : "Atsisiųsti",
     "Share with users or groups" : "Dalintis su naudotojais arba grupėmis",
     "can edit" : "gali redaguoti",
     "group" : "grupė",
