@@ -19,6 +19,7 @@ OC.L10N.register(
     "When shared show full event" : "Vis hele hendelsen når delt",
     "When shared show only busy" : "Vis kun opptatt når delt",
     "When shared hide this event" : "Skjul denne hendelsen når delt",
+    "Cancelled" : "Avbrutt",
     "Please add a title!" : "Vennligst lag en tittel!",
     "Please select a calendar!" : "Vennligst velg en kalender!",
     "Global" : "Global",
@@ -84,9 +85,11 @@ OC.L10N.register(
     "Month" : "Måned",
     "Today" : "I dag",
     "Share Calendar" : "Del kalender",
+    "Shared" : "Delt",
     "More" : "Mer",
     "Edit" : "Endre",
-    "CalDAV" : "CalDAV",
+    "Link" : "Lenke",
+    "Download" : "Last ned",
     "Share with users or groups" : "Del med brukere eller grupper",
     "can edit" : "kan endre",
     "group" : "gruppe",
