@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Wanneer gedeeld toon gehele gebeurtenis",
     "When shared show only busy" : "Wanneer gedeeld toon enkel beschikbaarheid",
     "When shared hide this event" : "Wanneer gedeeld verberg deze gebeurtenis",
+    "Confirmed" : "Bevestigd",
+    "Tentative" : "Voorlopig",
+    "Cancelled" : "Geannuleerd",
     "Please add a title!" : "Voeg een titel toe!",
     "Please select a calendar!" : "Selecteer een agenda!",
     "Global" : "Globaal",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Sluiten",
     "Location" : "Locatie",
     "Description" : "Beschrijving",
+    "Event status" : "Afspraak status",
+    "Visibility when sharing" : "Zichtbaarheid bij delen",
     "Export" : "Exporteer",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Wegens een upstream bug kan de kalender nu de asset pipeline mogelijkheid niet ondersteunen.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Neem contact op met de beheerder en vraag om de configuratieoptie \"asset-pipeline.enabled\" uit te schakelen.",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Week",
     "Month" : "Maand",
     "Today" : "Vandaag",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Sommige afspraken in de agenda zijn kapot. Controleer de JS console voor meer info.",
     "Share Calendar" : "Delen agenda",
+    "Shared" : "Gedeeld",
     "More" : "Meer",
     "Edit" : "Bewerk",
-    "CalDAV" : "CalDAV",
+    "Link" : "Link",
+    "Download" : "Downloaden",
     "Share with users or groups" : "Delen met gebruikers of groepen",
     "can edit" : "kan wijzigen",
     "group" : "groep",
