@@ -19,6 +19,7 @@ OC.L10N.register(
     "When shared show full event" : "Kiedy współdzieli pokaż całe wydarzenie",
     "When shared show only busy" : "Kiedy współdzieli pokaż tylko zajęty",
     "When shared hide this event" : "Kiedy współdzieli ukryj to wydarzenie",
+    "Cancelled" : "Przerwano",
     "Please add a title!" : "Proszę dodać tytuł!",
     "Please select a calendar!" : "Proszę wybrać kalendarz!",
     "Global" : "Ogólny",
@@ -84,9 +85,11 @@ OC.L10N.register(
     "Month" : "Miesiąc",
     "Today" : "Dziś",
     "Share Calendar" : "Współdziel kalendarz",
+    "Shared" : "Udostępniono",
     "More" : "Więcej",
     "Edit" : "Edytuj",
-    "CalDAV" : "CalDAV",
+    "Link" : "Link",
+    "Download" : "Pobierz",
     "Share with users or groups" : "Współdziel z grupami bądź użytkownikami",
     "can edit" : "może edytować",
     "group" : "grupa",
