@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Quando compartilhado mostrar evento completo",
     "When shared show only busy" : "Quando compartilhado mostrar apenas ocupado",
     "When shared hide this event" : "Quando compartilhado esconder este evento",
+    "Confirmed" : "Confirmado",
+    "Tentative" : "Tentativa",
+    "Cancelled" : "Cancelado",
     "Please add a title!" : "Por favor adicione um título!",
     "Please select a calendar!" : "Por favor selecione um calendário!",
     "Global" : "Global",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Fechar",
     "Location" : "Localização",
     "Description" : "Descrição",
+    "Event status" : "Status do evento",
+    "Visibility when sharing" : "Visível quando compartilhando",
     "Export" : "Exportar",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um bug a montante, o calendário não é atualmente capaz de fornecer suporte para o recurso de pipeline ativo.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor entre em contato com o administrador e pedir-lhes para desativar a opção de configuração \"asset-pipeline.enabled\".",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Semana",
     "Month" : "Mês",
     "Today" : "Hoje",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Alguns eventos neste calendário estão quebrados. Por favor, verifique o console JS para mais informações.",
     "Share Calendar" : "Compartilhar Calendário",
+    "Shared" : "Compartilhado",
     "More" : "Mais",
     "Edit" : "Editar",
-    "CalDAV" : "CalDAV",
+    "Link" : "Link",
+    "Download" : "Baixar",
     "Share with users or groups" : "Compartilhar com usuários ou grupos",
     "can edit" : "pode editar",
     "group" : "grupo",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "Novo calendário",
     "Import scheduled" : "Importar agendados",
     "Settings" : "Configurações",
+    "Skip simple event editor" : "Pular editor de eventos simples",
     "Import calendar" : "Importar calendário",
     "No Calendars selected for import" : "Nenhum Calendário foi selecionado para importação",
     "Primary CalDAV address" : "Endereço CalDAV primário",
