@@ -19,6 +19,7 @@ OC.L10N.register(
     "When shared show full event" : "Arată tot evenimentul la partajare",
     "When shared show only busy" : "Arată doar ocupat la partajare",
     "When shared hide this event" : "Ascunde evenimentul la partajare",
+    "Cancelled" : "Anulat",
     "Please add a title!" : "Adaugă un titlu!",
     "Please select a calendar!" : "Alege un calendar!",
     "Global" : "Global",
@@ -74,9 +75,11 @@ OC.L10N.register(
     "Month" : "Luna",
     "Today" : "Astăzi",
     "Share Calendar" : "Partajează calendarul",
+    "Shared" : "Partajat",
     "More" : "Mai mult",
     "Edit" : "Editează",
-    "CalDAV" : "CalDAV",
+    "Link" : "Legătură",
+    "Download" : "Descarcă",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "can edit" : "poate edita",
     "group" : "grup",
