@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Če je v souporabi, pokaži celoten dogodek",
     "When shared show only busy" : "Če je v souporabi, pokaži le podatek o časovni zadržanosti",
     "When shared hide this event" : "Če je v souporabi, skrij ta dogodek",
+    "Confirmed" : "Potrjeno",
+    "Tentative" : "Začasno",
+    "Cancelled" : "Preklicano",
     "Please add a title!" : "Dodajte naslov!",
     "Please select a calendar!" : "Izberite koledar!",
     "Global" : "Splošno",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Zapri",
     "Location" : "Mesto",
     "Description" : "Opis",
+    "Event status" : "Stanje dogodka",
+    "Visibility when sharing" : "Vidnost med souporabo",
     "Export" : "Izvozi",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Zaradi znanega hrošča v koledarju trenutno ni mogoča podpora zmožnosti skrčenja kode javascript in CSS.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Stopite v stik s sistemskim skrbnikom oziroma onemogočite nastavitev \"asset-pipeline.enabled\"",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Teden",
     "Month" : "Mesec",
     "Today" : "Danes",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Nekateri vpisani dogodki v koledarju so okvarjeni. Preverite konzolo JS za več podrobnosti.",
     "Share Calendar" : "Omogoči souporabo koledarja",
+    "Shared" : "V souporabi",
     "More" : "Več",
     "Edit" : "Uredi",
-    "CalDAV" : "CalDAV",
+    "Link" : "Povezava",
+    "Download" : "Prejmi",
     "Share with users or groups" : "Souporaba z uporabniki ali skupinami",
     "can edit" : "lahko ureja",
     "group" : "skupina",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "Nov koledar",
     "Import scheduled" : "Uvoz urnika",
     "Settings" : "Nastavitve",
+    "Skip simple event editor" : "Preskoči enostavni urejevalnik dogodkov",
     "Import calendar" : "Uvoz koledarja",
     "No Calendars selected for import" : "Ni navedenih koledarjev za uvoz",
     "Primary CalDAV address" : "Osnovni naslov CalDAV",
