@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
     "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
     "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
+    "Confirmed" : "E ripohuar",
+    "Tentative" : "Në tentativë",
+    "Cancelled" : "Anuluar",
     "Please add a title!" : "Ju lutemi, shtoni një titull!",
     "Please select a calendar!" : "Ju lutemi, përzgjidhni një kalendar",
     "Global" : "Globale",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Mbylle",
     "Location" : "Vendndodhje",
     "Description" : "Përshkrim",
+    "Event status" : "Gjendje veprimtarie",
+    "Visibility when sharing" : "Dukshmëri gjatë ndarjes me të tjerë",
     "Export" : "Eksportoji",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Për shkak të një të mete në degën kryesore, kalendari, hëpërhë, s’është në gjendje të ofrojë mbulim të veçorinë \"asset pipeline\".",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ju lutemi, lidhuni me përgjegjësin tuaj dhe kërkojini të çaktivizojë mundësinë \"asset-pipeline.enabled\" te formësimet.",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Javë",
     "Month" : "Muaj",
     "Today" : "Sot",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Disa nga veprimtaritë në këtë kalendar janë të dëmtuara. Ju lutemi, për më tepër të dhëna, kontrolloni te konsola JS.",
     "Share Calendar" : "Ndani Kalendar",
+    "Shared" : "E ndarë",
     "More" : "Më tepër",
     "Edit" : "Përpunoni",
-    "CalDAV" : "CalDAV",
+    "Link" : "Lidhje",
+    "Download" : "Shkarkoje",
     "Share with users or groups" : "Ndajeni me përdorues ose grupe",
     "can edit" : "mund të përpunojnë",
     "group" : "grup",
@@ -121,6 +129,7 @@ OC.L10N.register(
     "New calendar" : "Kalendar i ri",
     "Import scheduled" : "Importimi u planifikua",
     "Settings" : "Rregullime",
+    "Skip simple event editor" : "Anashkaloje përpunuesin e thjeshtë të veprimtarive",
     "Import calendar" : "Importo kalendar",
     "No Calendars selected for import" : "S’ka Kalendarë të përzgjedhur për import",
     "Primary CalDAV address" : "Adresë CalDAV parësore",
