@@ -19,6 +19,9 @@ OC.L10N.register(
     "When shared show full event" : "Paylaşıldığında etkinliği göster",
     "When shared show only busy" : "Paylaşıldğında sadece meşgulleri göster",
     "When shared hide this event" : "Paylaşıldığında bu etkinliği gizle",
+    "Confirmed" : "Onaylı",
+    "Tentative" : "Geçici",
+    "Cancelled" : "İptal edildi",
     "Please add a title!" : "Lütfen bir başlık ekleyin!",
     "Please select a calendar!" : "Lütfen bir takvim seçin!",
     "Global" : "Evrensel",
@@ -76,6 +79,8 @@ OC.L10N.register(
     "Close" : "Kapat",
     "Location" : "Konum",
     "Description" : "Açıklama",
+    "Event status" : "Olay durumu",
+    "Visibility when sharing" : "Paylaşılırken görünürlük",
     "Export" : "Dışa aktar",
     "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Üst yazılım hatası nedeniyle, takvim şu anda asset pipeline özelliğine destek veremiyor.",
     "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Lütfen yöneticinizle iletişime geçip \"asset-pipeline.enabled\" yapılandırma seçeneğinin devre dışı bırakılmasını talep edin.",
@@ -83,10 +88,13 @@ OC.L10N.register(
     "Week" : "Hafta",
     "Month" : "Ay",
     "Today" : "Bugün",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Bu takvimdeki bazı etkinlikler kırık. Daha fazla bilgi için JS konsolunu kontrol edin.",
     "Share Calendar" : "Takvimi Paylaş",
+    "Shared" : "Paylaşılan",
     "More" : "Daha fazla",
     "Edit" : "Düzenle",
-    "CalDAV" : "CalDAV",
+    "Link" : "Bağlantı",
+    "Download" : "İndir",
     "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
     "can edit" : "düzenleyebilir",
     "group" : "grup",
